@@ -36,6 +36,9 @@ class my_graph(gr.flow_graph):
                           help="pcm input device name.  E.g., hw:0,0 or /dev/dsp")
         parser.add_option("-r", "--sample-rate", type="eng_float", default=48000,
                           help="set sample rate to RATE (48000)")
+        parser.add_option("-N", "--nsamples", type="eng_float", default=None,
+                          help="number of samples to collect [default=+inf]")
+     
         (options, args) = parser.parse_args ()
         if len(args) != 1:
             parser.print_help()
@@ -45,7 +48,12 @@ class my_graph(gr.flow_graph):
         sample_rate = int(options.sample_rate)
         src = audio.source (sample_rate, options.audio_input)
         dst = gr.file_sink (gr.sizeof_float, filename)
-        self.connect((src, 0), dst)
+
+        if options.nsamples is None:
+            self.connect((src, 0), dst)
+        else:
+            head = gr.head(gr.sizeof_float, int(options.nsamples))
+            self.connect((src, 0), head, dst)
 
 
 if __name__ == '__main__':
