@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-from gnuradio import gr
+from gnuradio import gr, gru
 from gnuradio import usrp
 from gnuradio.eng_option import eng_option
 from optparse import OptionParser
@@ -21,7 +21,7 @@ def main ():
 
     fg = gr.flow_graph ()
 
-    u = usrp.source_s (0, options.decim, 1, options.mux, 0)
+    u = usrp.source_s (0, options.decim, 1, gru.hexint(options.mux), 0)
     u.set_rx_freq (0, options.ddc_freq)
     u.set_pga (0, options.gain)
     u.set_pga (1, options.gain)
