@@ -34,7 +34,7 @@ class wfm_rx_graph (stdgui.gui_flow_graph):
                           help="select USRP Rx side A or B (default=A)")
         parser.add_option("-f", "--freq", type="eng_float", default=100.1e6,
                           help="set frequency to FREQ", metavar="FREQ")
-        parser.add_option("-g", "--gain", type="eng_float", default=None,
+        parser.add_option("-g", "--gain", type="eng_float", default=40,
                           help="set gain in dB (default is midpoint)")
         parser.add_option("-V", "--volume", type="eng_float", default=None,
                           help="set volume (default is midpoint)")
