@@ -33,13 +33,16 @@ class wfm_rx_graph (stdgui.gui_flow_graph):
                           help="select USRP Rx side A or B (default=A)")
         parser.add_option("-f", "--freq", type="eng_float", default=100.1e6,
                           help="set frequency to FREQ", metavar="FREQ")
-        parser.add_option("-g", "--gain", type="eng_float", default=None,
+        parser.add_option("-g", "--gain", type="eng_float", default=40,
                           help="set gain in dB (default is midpoint)")
+        parser.add_option("-s", "--squelch", type="eng_float", default=0,
+                          help="set squelch level (default is 0)")
         parser.add_option("-V", "--volume", type="eng_float", default=None,
                           help="set volume (default is midpoint)")
         parser.add_option("-O", "--audio-output", type="string", default="",
                           help="pcm device name.  E.g., hw:0,0 or surround51 or /dev/dsp")
 
+
         (options, args) = parser.parse_args()
         if len(args) != 0:
             parser.print_help()
@@ -98,6 +101,7 @@ class wfm_rx_graph (stdgui.gui_flow_graph):
         self.connect (self.u, chan_filt, self.guts)
         self.connect ((self.guts, 0), self.volume_control_l, (audio_sink, 0))
         self.connect ((self.guts, 1), self.volume_control_r, (audio_sink, 1))
+        self.guts.stereo_carrier_pll_recovery.squelch_enable(True);
 
         self._build_gui(vbox, usrp_rate, demod_rate, audio_rate)
 
@@ -109,7 +113,7 @@ class wfm_rx_graph (stdgui.gui_flow_graph):
         if options.volume is None:
             g = self.volume_range()
             options.volume = float(g[0]+g[1])/2
-            
+
         if abs(options.freq) < 1e6:
             options.freq *= 1e6
 
@@ -117,6 +121,7 @@ class wfm_rx_graph (stdgui.gui_flow_graph):
 
         self.set_gain(options.gain)
         self.set_vol(options.volume)
+        self.guts.stereo_carrier_pll_recovery.set_lock_threshold(options.squelch);
         if not(self.set_freq(options.freq)):
             self._set_status_msg("Failed to set initial frequency")
 
@@ -209,6 +214,12 @@ class wfm_rx_graph (stdgui.gui_flow_graph):
                                         weight=3, range=self.subdev.gain_range(),
                                         callback=self.set_gain)
         hbox.Add((5,0), 0)
+
+        myform['sqlch_thrsh'] = \
+            form.quantized_slider_field(parent=self.panel, sizer=hbox, label="Stereo Squelch Threshold",
+                                        weight=3, range=(0.0,1.0,0.01),
+                                        callback=self.guts.stereo_carrier_pll_recovery.set_lock_threshold)
+        hbox.Add((5,0), 0)
         vbox.Add(hbox, 0, wx.EXPAND)
 
         try:
